package org.daligo.app;

import java.io.File;
import java.io.FilenameFilter;
import java.util.ArrayList;
import java.util.List;

import android.app.ListActivity;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.DeadObjectException;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.Toast;

class Mp3Filter implements FilenameFilter {
	public boolean accept(File dir, String name) {
		return (name.endsWith(".mp3"));
	}
}

public class MusicListActivity extends ListActivity {

	public static final String MEDIA_PATH = new String("/sdcard/");
	private List<String> songs = new ArrayList<String>();
	private MusicPlayerInterface mpInterface;
	Button PlayPause;
	
	@Override
	public void onCreate(Bundle icicle) {
		super.onCreate(icicle);
		setContentView(R.layout.music_list_activity);
		this.bindService(new Intent(MusicListActivity.this,MusicPlayerService.class), 
				mConnection, Context.BIND_AUTO_CREATE);
		PlayPause = (Button)findViewById(R.id.play_pause);
		final Button Stop = (Button)findViewById(R.id.stop);
		final Button Go = (Button)findViewById(R.id.daligo);
			
		Go.setOnClickListener(new OnClickListener(){
			@Override
			public void onClick(View v) {
				finish();
			}
        });
						
        PlayPause.setOnClickListener(new OnClickListener(){
        	public void onClick(View v){
	           	try {
					if(PlayPauseAudio()==0){ 
						PlayPause.setText("pause"); 
					}else{ 
						PlayPause.setText("play"); 
					}
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
	        }
        });
        
        Stop.setOnClickListener(new OnClickListener(){ 
        	public void onClick(View v){
        		try {
					mpInterface.stop();
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
        		PlayPause.setText("play");
        	}
        });
        
     }
    
    private int PlayPauseAudio() throws RemoteException{
    	if(!mpInterface.IsPlay()){ 		
    		int first=mpInterface.current();		
    		if(first==-1)
    			mpInterface.playFile(0);
    		else
    			mpInterface.play();  				
        	Toast.makeText(getApplicationContext(), "play", Toast.LENGTH_SHORT).show();
        	return 0;
          	}
    	else{ 
   		mpInterface.pause();
   		Toast.makeText(getApplicationContext(), "pause", Toast.LENGTH_SHORT).show();
   		return 1;
    	}
    }
    	
	public void updateSongList() throws RemoteException {
		try {
			File home = new File(MEDIA_PATH);
			File fileList[] = home.listFiles(new Mp3Filter());
			mpInterface.clearPlaylist();
			if (fileList != null) {
				for (File file : fileList ) {
					songs.add(file.getName());
					mpInterface.addSongPlaylist(file.getName());
				}	
				ArrayAdapter<String> songList = new ArrayAdapter<String>(this,
						R.layout.song_item, songs);
				setListAdapter(songList);
			}
		} catch(DeadObjectException e) {
			Log.e(getString(R.string.app_name), e.getMessage());
		}
	}

	@Override
	protected void onListItemClick(ListView l, View v, int position, long id) {
		try {
			mpInterface.stop();
			PlayPause.setText("pause");
			mpInterface.playFile(position);
		} catch(DeadObjectException e) {
			Log.e(getString(R.string.app_name), e.getMessage());
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
		
	private ServiceConnection mConnection = new ServiceConnection()
    {
		public void onServiceConnected(ComponentName className, IBinder service) {
			mpInterface = MusicPlayerInterface.Stub.asInterface((IBinder)service);
			try {
				updateSongList();
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		public void onServiceDisconnected(ComponentName className) {
			mpInterface = null;
		}
    };

}